<?php
#-------------------------------------------------------------------------------
#
# Module : AdvancedContent (c) 2010 by Georg Busch (georg.busch@gmx.net)
#          a content management tool for CMS Made Simple
#          The projects homepage is dev.cmsmadesimple.org/projects/content2/
#          CMS Made Simple is (c) 2004-2010 by Ted Kulp
#          The projects homepage is: cmsmadesimple.org
# Version: 0.6.1
# File   : action.savePrefs.php
# Purpose: saves the preferences in the database
# License: GPL
#
#-------------------------------------------------------------------------------

if(!isset($gCms)) exit;

if(isset($params['submit']) || isset($params['submit_prefs'])) 
{
	if(isset($params['uninstall_action']))
		$this->SetPreference('uninstall_action', $params['uninstall_action']);
	
	if(isset($params['feu_access']))
		$this->SetPreference('feu_access', implode(';',$this->CleanArray($params['feu_access'])));
	
	if(isset($params['redirect_page']))
		$this->SetPreference('redirect_page', $params['redirect_page']);
	
	if(isset($params['redirect_params']))
		$this->SetPreference('redirect_params', $params['redirect_params']);
	
	if(isset($params['evaluate_smarty']))
		$this->SetPreference('evaluate_smarty', $params['evaluate_smarty']);
	
	if(isset($params['feu_action']))
		$this->SetPreference('feu_action', $params['feu_action']);
	
	if(isset($params['block_display_settings']))
		$this->SetPreference('block_display_settings', $params['block_display_settings']);
	
	if(isset($params['message_display_settings']))
		$this->SetPreference('message_display_settings', $params['message_display_settings']);
	
	if(isset($params['group_display_settings']))
		$this->SetPreference('group_display_settings', $params['group_display_settings']);
	
	if(isset($params['show_advancedcontent_options']))
		$this->SetPreference('show_advancedcontent_options', $params['show_advancedcontent_options']);
}
if(isset($params['item_type']) && isset($params['item_display'])) 
{
	$this->SetItemDisplay($params['item_type'], $params['item_id'], $params['content_id'], $params['template_id'], $params['item_display']);
}
if(isset($params['set_default']))
{
	$this->SetPreference('default_'.$params['set_default'].'_tpl', $params['tpl_id']);
}
if(isset($params['ajax'])) 
{
	echo '<div class="pagemcontainer"><p class="pagemessage">'.$this->lang('prefsupdated').'</p></div>';
	exit;
}
else 
{
	$this->Redirect($id, 'defaultadmin', $returnid, array('message' => 'prefsupdated', 'submit' => true));
}
?>
